Skip to contents

Function interacts with the computer clipboard. To use, start by copying a row or column in excel that you want coded as a vector in R. Run clip_to_vec() to change the system clipboard to the string of R code that defines an equivalent vector, then paste into R script.

Usage

clip_to_vec()

Value

Nothing