Implants a dataframe into a specified cell range into an openxlsx2 workbook after validation checks have been completed.
Arguments
- wb
An openxlsx2 workbook object
- new_dat
A dataframe containing the new data to be implanted
- cell_range
Character string specifying the range of cells to copy into (e.g., "A1:C3")
- sheet
Character string or numeric index specifying the sheet to copy into
- numeric_flag
Logical indicating whether the data should be converted to numeric (default: TRUE)
- debug_mode
Logical indicating whether to highlight updated cells in red (default: FALSE)